(function ($) {
    'use strict';

    Drupal.behaviors.vsfs = {
        attach: function (context, settings) {
            if (context !== document) {
                return;
            }
            $('.search-icon', context).each(function () {

                var $this = $(this);
                if (!$this.data('initialized')) {
                    $this.on('click', function (e) {
                        e.preventDefault();
                        var ajaxSettings = {
                            url: '/voice-search-feature/data',
                            success: function (response) {
                                var datatoShow = response[0].data;
                                var $responseHtml = $('<div>').html(datatoShow);
                                var speakNowText = $responseHtml.find('#voice-search-speak-now-default-text').html();
                                var listeningText = $responseHtml.find('#voice-search-speak-now-search-text').html();
                                var tryAgainText = $responseHtml.find('#voice-search-retry').html();
                                var imageIcon = $responseHtml.find('.search-icon-2').attr('src');
                                var SpeechRecognition = window.SpeechRecognition || window.webkitSpeechRecognition || window.mozSpeechRecognition || window.msSpeechRecognition;

                                if (SpeechRecognition) {
                                    var spokenText = "";
                                    var recognition = new SpeechRecognition();
                                    recognition.interimResults = false;
                                    recognition.maxAlternatives = 5;

                                    recognition.onstart = function() {
                                        var dialogContent = $('<div>', {
                                            id: 'voice-search-dialog-content',
                                            html: speakNowText
                                        });

                                        var img = $('<img>', {
                                            src: imageIcon,
                                            alt: 'Voice Search Icon',
                                            class: 'voice-imgspeak'
                                        });

                                        var pulseRing = $('<div>', {
                                            class: 'pulse-ring'
                                        });

                                        var wrapper = $('<div>', {
                                            class: 'voice-wrapper1'
                                        });

                                        wrapper.append(img).append(pulseRing);
                                        dialogContent.append(wrapper);
                                        Drupal.dialog(dialogContent).showModal();
                                    }

                                    recognition.onend = function() {
                                        if (spokenText.trim() === "") {
                                            
                                            $('#voice-search-dialog-content').html('Did Not Get. Please Try Again !!');
                                            recognition.stop();
                                        } else {
                                            
                                        }
                                        setTimeout(function() {
                                            $('#voice-search-dialog-content').closest('.ui-dialog-content').dialog('close');
                                        }, 2000);
                                    }

                                    recognition.onspeechstart = function() {
                                        $('#voice-search-dialog-content').html(listeningText);

                                        var containerDiv = $('<div>', {
                                            class: 'voice-wrapper1'
                                        });

                                        var img = $('<img>', {
                                            src: imageIcon,
                                            alt: 'Voice Search Icon',
                                            class: 'voice-imgspeak'
                                        });

                                        var pulseRing = $('<div>', {
                                            class: 'pulse-ring'
                                        });

                                        containerDiv.append(img).append(pulseRing);
                                        $('#voice-search-dialog-content').append(containerDiv);
                                       

                                        
                                    };

                                    recognition.onresult = function(event) {
                                        var transcript = event.results[0][0].transcript;
                                       
                                        spokenText = transcript;

                                        $('span#highlighted-text').each(function() {
                                            var $this = $(this);
                                            $this.replaceWith($this.html());
                                        });

                                        var foundText = false;
                                        var escapedSpokenText = spokenText.replace(/[-\/\\^$*+?.()|[\]{}]/g, '\\$&');
                                        var regex = new RegExp(escapedSpokenText, 'gi');

                                        $('body *:visible').each(function() {
                                            var $this = $(this);

                                            // Get only the visible text content without any HTML tags
                                            var visibleText = $this.contents().filter(function() {
                                                return this.nodeType === 3; // Node type 3 is a text node
                                            }).text();

                                            if (regex.test(visibleText)) {
                                                foundText = true;

                                                var highlightedHtml = visibleText.replace(regex, function(match) {
                                                    return '<span id="highlighted-text" style="background-color: yellow;">' + match + '</span>';
                                                });
                                                $this.html(function(_, oldHtml) {
                                                    return oldHtml.replace(visibleText, highlightedHtml);
                                                });

                                                var $highlighted = $('#highlighted-text');
                                                var offset = $highlighted.offset();
                                                var top = offset.top;
                                                var viewportHeight = $(window).height();
                                                var targetScroll = top - (viewportHeight / 2);

                                                $('html, body').animate({
                                                    scrollTop: targetScroll
                                                }, 500);

                                                // return false;
                                            }
                                        });

                                        if (foundText) {
                                            $('#voice-search-dialog-content').html('Found: "' + spokenText + '"');
                                        } else {
                                            $('#voice-search-dialog-content').html(tryAgainText);
                                        }
                                        recognition.stop();   
                                        setTimeout(function() {
                                            $('#voice-search-dialog-content').closest('.ui-dialog-content').dialog('close');
                                        }, 2000); 
                                    }

                                    recognition.onerror = function(event) {
                                        console.error('Speech recognition error: ', event.error);
                                        if (event.error === 'not-allowed') {
                                            alert('Microphone access is blocked or not connected. Please check !!');
                                        }
                                        recognition.stop();
                                        setTimeout(function() {
                                            $('#voice-search-dialog-content').closest('.ui-dialog-content').dialog('close');
                                        }, 2000); 
                                    }

                                    $('.close-voice-search').click(function() {
                                        recognition.stop();
                                    });

                                    recognition.start();
                                }                
                            },
                            error: function () {
                                console.error('Failed to load voice search feature data.');
                            }
                        };
                        Drupal.ajax(ajaxSettings).execute();    
                    });
                    $this.data('initialized', true);
                }     
            });
        }
    }
})(jQuery);
