<?php

namespace Drupal\vsf\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Voice search feature settings for this site.
 */
final class VoiceSearchForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'vsf_voice_search';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['vsf.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config('vsf.settings');
    $form['enable_feature'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Please check the box to enable feature.'),
      '#default_value' => $config->get('enable_feature') ?: '',
    ];
    $form['speak_now_text'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Speak Now Text'),
      '#default_value' => $config->get('speak_now_text') ?: 'Speak Now',
      '#description' => $this->t('Text to display when the microphone is activated.'),
      '#states' => [
        'visible' => [
          ':input[name="enable_feature"]' => ['checked' => TRUE],
        ],
      ],
    ];
    $form['listening_text'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Listening Text'),
      '#default_value' => $config->get('listening_text') ?: 'Listening..',
      '#description' => $this->t('Text to display while the microphone is listening.'),
      '#states' => [
        'visible' => [
          ':input[name="enable_feature"]' => ['checked' => TRUE],
        ],
      ],
    ];
    $form['did_not_get_text'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Did not get, try again Text'),
      '#default_value' => $config->get('did_not_get_text') ?: 'Didnot get, please try again',
      '#description' => $this->t('Text to display when the speech input is not recognized.'),
      '#states' => [
        'visible' => [
          ':input[name="enable_feature"]' => ['checked' => TRUE],
        ],
      ],
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $config = $this->config('vsf.settings');
    $config->set('enable_feature', $form_state->getValue('enable_feature'))
      ->set('speak_now_text', $form_state->getValue('speak_now_text'))
      ->set('listening_text', $form_state->getValue('listening_text'))
      ->set('did_not_get_text', $form_state->getValue('did_not_get_text'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
